"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMessageConnection = void 0;
const vscode_jsonrpc_1 = require("vscode-jsonrpc");
const reader_1 = require("./reader");
const writer_1 = require("./writer");
/**
 * Create VSCode JSON RPC `MessageConnection` with Web Worker.
 * @param worker
 * @param logger
 */
exports.createMessageConnection = (worker, logger = createConsoleLogger()) => {
    const conn = vscode_jsonrpc_1.createMessageConnection(reader_1.createMessageReader(worker), writer_1.createMessageWriter(worker), logger);
    conn.onClose(() => conn.dispose());
    // Return MessageConnection wrapped in Promise to match the Web Socket version.
    return Promise.resolve(conn);
};
const createConsoleLogger = () => ({
    error: (message) => console.error(message),
    warn: (message) => console.warn(message),
    info: (message) => console.info(message),
    log: (message) => console.log(message),
});
//# sourceMappingURL=connection.js.map