"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMessageReader = void 0;
const vscode_jsonrpc_1 = require("vscode-jsonrpc");
exports.createMessageReader = (worker) => {
    const messageEmitter = new vscode_jsonrpc_1.Emitter();
    const errorEmitter = new vscode_jsonrpc_1.Emitter();
    // These are not used, but required by the interface.
    const closeEmitter = new vscode_jsonrpc_1.Emitter();
    const partialMessageEmitter = new vscode_jsonrpc_1.Emitter();
    const messageHandler = (event) => {
        messageEmitter.fire(event.data);
    };
    const errorHandler = (error) => {
        errorEmitter.fire(error);
    };
    worker.addEventListener("message", messageHandler);
    worker.addEventListener("error", errorHandler);
    worker.addEventListener("messageerror", errorHandler);
    return {
        get onError() {
            return errorEmitter.event;
        },
        get onClose() {
            return closeEmitter.event;
        },
        get onPartialMessage() {
            return partialMessageEmitter.event;
        },
        listen(callback) {
            return messageEmitter.event(callback);
        },
        dispose() {
            worker.removeEventListener("message", messageHandler);
            worker.removeEventListener("error", errorHandler);
            worker.removeEventListener("messageerror", errorHandler);
            messageEmitter.dispose();
            errorEmitter.dispose();
            closeEmitter.dispose();
            partialMessageEmitter.dispose();
        },
    };
};
//# sourceMappingURL=reader.js.map