"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMessageWriter = void 0;
const vscode_jsonrpc_1 = require("vscode-jsonrpc");
exports.createMessageWriter = (worker) => {
    const errorEmitter = new vscode_jsonrpc_1.Emitter();
    const closeEmitter = new vscode_jsonrpc_1.Emitter();
    let errorCount = 0;
    const errorHandler = (error) => {
        errorEmitter.fire([toError(error), undefined, ++errorCount]);
    };
    worker.addEventListener("error", errorHandler);
    return {
        get onError() {
            return errorEmitter.event;
        },
        get onClose() {
            return closeEmitter.event;
        },
        async write(msg) {
            try {
                worker.postMessage(msg);
            }
            catch (e) {
                errorEmitter.fire([toError(e), msg, ++errorCount]);
            }
        },
        end() { },
        dispose() {
            worker.removeEventListener("error", errorHandler);
            errorEmitter.dispose();
            closeEmitter.dispose();
        },
    };
};
const toError = (err) => err instanceof Error ? err : new Error((err === null || err === void 0 ? void 0 : err.message) || "Unknown error");
//# sourceMappingURL=writer.js.map